/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "MListCtrl.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "MListCtrl.h"


BEGIN_EVENT_TABLE(CMListCtrl,wxListCtrl)
	EVT_LIST_COL_RIGHT_CLICK(-1, CMListCtrl::ColumnRightClick)
	EVT_MENU(-1, CMListCtrl::MenuItemClick)
END_EVENT_TABLE()

/* 
 * CMListCtrl class is a derived class from wxListCtrl to allow us
 * use column hiding, sorting and other similar stuff. All other
 * listctrl classes (CServerListCtrl, CSearchListCtrl etc) are derived
 * from this class instead of wxListCtrl.
 */
CMListCtrl::CMListCtrl( 
	wxWindow *parent, wxWindowID id,
	const wxPoint &position, const wxSize& size, long style 
) : wxListCtrl( parent, id, position, size, style ) {

}

CMListCtrl::~CMListCtrl() {

}

/*
 * Column right click event handler. We generate the column-hiding
 * context menu here, according to available columns. Note that
 * menu item ID's are generated from base constant COL_SERVER + column
 * number. Also, we need to use ScreenToClient() to get the right
 * coordinates for popping up the menu, as ::wxGetMousePosition returns
 * screen coordinates.
 */
void CMListCtrl::ColumnRightClick(wxListEvent &event) {
	wxMenu *colmenu = new wxMenu();
	wxListItem listitem;
	listitem.SetMask(wxLIST_MASK_TEXT);
	for (int i=0; i<GetColumnCount(); i++) {
		GetColumn(i, listitem);
		colmenu->AppendCheckItem(M_LISTCOL+i, listitem.GetText());
		colmenu->Check(M_LISTCOL+i, GetColumnWidth(i)>10 ? true : false);
	}
	PopupMenu(colmenu, event.GetPoint());
}

/*
 * Popup-menu item selections. Hides/shows the selected column by
 * setting its width to 0 or -1 (latter one sets the width according
 * to longest item in the column).
 */
void CMListCtrl::MenuItemClick(wxCommandEvent &event) {
	int col = event.GetId()-M_LISTCOL;
	SetColumnWidth(col, (GetColumnWidth(col)>10 ? 0 : 80));
}

/*
 * Here we load column widths data from configuration object. Location
 * argument should point to where to read the data, and widths[] will
 * be the array to store the loaded data in. Count must reflect the
 * number of items in widths[] array. Remember to pass the trailing
 * slash to location.
 */
void CMListCtrl::LoadColumnWidths(wxString location, int widths[], int count) {
	wxConfigBase *config = wxConfigBase::Get();
	for (int i=0; i<count; i++) {
		config->Read(
			wxString::Format(wxT("%s%d"), location.c_str(), i), 
			&widths[i], 
			-1
		);
	}
}

/*
 * Here we save the column widths data into configuration object. Location
 * is the path to where to save the data ("/Lists/Downloadlist/" for example).
 * Remember to pass the trailing slash to the location.
 */
void CMListCtrl::SaveColumnWidths(wxString location) {
	wxConfigBase *config = wxConfigBase::Get();
	for (int i=0; i<GetColumnCount(); i++) {
		config->Write(
			wxString::Format(wxT("%s%d"), location.c_str(), i), 
			GetColumnWidth(i)
		);
	}
}
