/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "ServerWnd.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h". 
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "ServerWnd.h"
#include "ServerListCtrl.h"

/*
 * CServerWnd class.
 */

BEGIN_EVENT_TABLE(CServerWnd,wxPanel)
	EVT_BUTTON(ID_ADDTOLIST, CServerWnd::AddNewServer)
	EVT_BUTTON(ID_UPDATE, CServerWnd::UpdateFromURL)
END_EVENT_TABLE()

/* 
 * Constructor for server window. Loads the server dialog and sets LogBook 
 * images.
 */
CServerWnd::CServerWnd( 
	wxWindow *parent, wxWindowID id, const wxPoint &position, 
	const wxSize& size, long style ) 
: wxPanel( parent, id, position, size, style ) {
	ServerWnd( this, TRUE ); 
	Hide();

	m_imagelist = new wxImageList(16, 16);
	m_imagelist->Add(Icons(1));
	m_imagelist->Add(Icons(2));
	
	m_logbook->AssignImageList(m_imagelist);            
	m_logbook->SetPageImage(0, 0);
	m_logbook->SetPageImage(1, 1);
	m_logbook->SetPageImage(2, 1);

}

/*
 * Destructor for server window. All shutdown functions go here.
 */
CServerWnd::~CServerWnd() {
}

/*
 * These three almost identical methods add a line of [text] into the
 * corresponding log boxes, optionally also displaying it in statusbar.
 * All lines will be added current date/time before it, and textboxes
 * are scrolled to display the last added line.
 */
void CServerWnd::AddDebugLine(wxString text, bool statusbar) {
	wxDateTime now = wxDateTime::Now();
	text = wxString::Format(
		wxT("\n[%s] %s"), now.Format(wxT("%c")).c_str(), text.c_str()
	);
	GetDlgItem(ID_DEBUGLOG)->AppendText(text);
	GetDlgItem(ID_DEBUGLOG)->ShowPosition(GetDlgItem(ID_DEBUGLOG)->GetLastPosition());
	if (statusbar) {
		xmuleDlg->SetStatusText(text, 0);
	}
}

void CServerWnd::AddLogLine(wxString text, bool statusbar) {
	wxDateTime now = wxDateTime::Now();
	text = wxString::Format(
		wxT("\n[%s] %s"), now.Format(wxT("%c")).c_str(), text.c_str()
	);
	GetDlgItem(ID_LOG)->AppendText(text);
	GetDlgItem(ID_LOG)->ShowPosition(GetDlgItem(ID_LOG)->GetLastPosition());
	if (statusbar) {
		xmuleDlg->SetStatusText(text, 0);
	}
}

void CServerWnd::AddServerLogLine(wxString text, bool statusbar) {
	wxDateTime now = wxDateTime::Now();
	text = wxString::Format(
		wxT("\n[%s] %s"), now.Format(wxT("%c")).c_str(), text.c_str()
	);
	GetDlgItem(ID_SERVERINFO)->AppendText(text);
	GetDlgItem(ID_SERVERINFO)->ShowPosition(GetDlgItem(ID_SERVERINFO)->GetLastPosition());
	if (statusbar) {
		xmuleDlg->SetStatusText(text, 0);
	}
}

/*
 * Add new server to servers list.
 */
void CServerWnd::AddNewServer() {
	AddDebugLine(wxT("Add New Server button clicked."));
}

/*
 * Downloads the server.met file from given URL and adds any new servers found
 * to server list.
 */
void CServerWnd::UpdateFromURL() {
	AddDebugLine(wxT("Update Server List from URL button clicked."));
}

