/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "StatusBar.h"
#endif

// For compilers that support precompilation
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "StatusBar.h"

/*
 * StatusBar class is a custom class for displaying the status bar on the bottom
 * of the dialog window. It loads the images, sets the texts and moves them 
 * around as window size changes.
 */
 
BEGIN_EVENT_TABLE(StatusBar, wxStatusBar)
	EVT_SIZE(StatusBar::OnSize)
END_EVENT_TABLE()

/*
 * Constructor for our custom status bar. Sets up four fields and creates the
 * bitmaps/textcontrols with default values.
 */
StatusBar::StatusBar(wxWindow *parent) : wxStatusBar(parent, -1) {
	int widths[] = {-1, 200, 200, 150};

	SetFieldsCount(4);
	SetStatusWidths(4, widths);
	
	m_userbmp = new wxStaticBitmap(this, -1, StatusBarBitmaps(0));
	m_usertxt = new wxStaticText(this, -1, _("Users: 64K(745K) "
						"| Files: 2.99M (123M)"));
	
	m_updownbmp = new wxStaticBitmap(this, -1, StatusBarBitmaps(1));
	m_updowntxt = new wxStaticText(this, -1, _("Up: 10.0kb/s | "
						"Down: 45.4kb/s"));
	
	m_serverbmp = new wxStaticBitmap(this, -1, StatusBarBitmaps(2));
	m_servertxt = new wxStaticText(this, -1, _("Razorback"));
}

/*
 * Destructor for our custom statusbar.
 */
StatusBar::~StatusBar() {
}

/*
 * OnSize event function. Here we recalculate the positions of all items and
 * place them into right locations relative to statusbar rectangles.
 */
void StatusBar::OnSize(wxSizeEvent& event) {
	wxRect rect;
	
	GetFieldRect(1, rect);
	m_usertxt->SetSize(rect.x+2, rect.y+2, rect.width-20, rect.height-4);
	m_userbmp->Move(rect.x + 2, rect.y + 2);
	m_usertxt->Move(rect.x + 18, rect.y + 2);

	GetFieldRect(2, rect);
	m_updowntxt->SetSize(rect.x+2, rect.y+2, rect.width-20, rect.height-4);
	m_updownbmp->Move(rect.x + 2, rect.y + 2);
	m_updowntxt->Move(rect.x + 18, rect.y + 2);
	
	GetFieldRect(3, rect);
	m_servertxt->SetSize(rect.x+2, rect.y+2, rect.width-20, rect.height-4);
	m_serverbmp->Move(rect.x + 2, rect.y + 2);
	m_servertxt->Move(rect.x + 18, rect.y + 2);
		
	event.Skip();
}

