/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef __GNUG__
	#pragma implementation "TransferWnd.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "TransferWnd.h"

BEGIN_EVENT_TABLE(CTransferWnd,wxPanel)
	/* Button events for changing the content of splitter frame content */
	EVT_BUTTON(ID_UPLOAD, CTransferWnd::ChangeToQueue)
	EVT_BUTTON(ID_QUEUE, CTransferWnd::ChangeToKnown)
	EVT_BUTTON(ID_KNOWN, CTransferWnd::ChangeToUpload)
END_EVENT_TABLE()

/*
 * Contructor for Transfer Window.
 */
CTransferWnd::CTransferWnd( 
	wxWindow *parent, wxWindowID id, const wxPoint &position, 
	const wxSize& size, long style ) 
: wxPanel( parent, id, position, size, style ) {
	config = wxConfigBase::Get();
	CreateControls();
	Hide();
}

/* Destructor for Transfer window */
CTransferWnd::~CTransferWnd() {
	config->Write(wxT("/Frame/SashPosition"), splatter->GetSashPosition());
}

/*
 * Changes the content of lower splitterwindow frame from Upload to Queue.
 */
void CTransferWnd::ChangeToQueue() {
	queue = new wxPanel(splatter, -1);
	QueuePanel(queue);
	splatter->ReplaceWindow(upload, queue);
	delete upload;
}

/*
 * Changes the content of lower splitterwindow frame from Upload to Known.
 */
void CTransferWnd::ChangeToKnown() {
	known = new wxPanel(splatter, -1);
	KnownPanel(known);
	splatter->ReplaceWindow(queue, known);
	delete queue;
}

/*
 * Changes the content of lower splitterwindow frame from Known to Upload.
 */
void CTransferWnd::ChangeToUpload() {
	upload = new wxPanel(splatter, -1);
	UploadPanel(upload);
	splatter->ReplaceWindow(known, upload);
	delete known;
}

/*
 * Creates the main layout of Transfer page - the splitter window, and
 * two static box sizers to bottom.
 */
void CTransferWnd::CreateControls() {
	int sashpos;
	config->Read(wxT("Frame/SashPosition"), &sashpos, 300);
	wxFlexGridSizer *mainsizer = new wxFlexGridSizer( 2, 0, 0, 0);
	mainsizer->AddGrowableCol( 0 );
	mainsizer->AddGrowableRow( 0 );

	/* Set up the splitter window and its contents */
	splatter = new wxSplitterWindow(
		this, ID_SPLITTER, wxDefaultPosition, wxSize(200,160), 
		wxSP_3DSASH|wxSP_NOBORDER|wxSP_LIVE_UPDATE
	);
	splatter->SetMinimumPaneSize( 30 );
	download = new wxPanel(splatter, -1);
	DownloadPanel(download);
	upload = new wxPanel(splatter, -1);
	UploadPanel(upload);

	splatter->SplitHorizontally(download, upload, sashpos);	
	mainsizer->Add(splatter, 0, wxGROW|wxEXPAND, 5);
	
	/* Set up the two static text boxes to the bottom of the frame. */
	wxBoxSizer *item2 = new wxBoxSizer( wxHORIZONTAL );
	wxStaticText *item3 = new wxStaticText(
 		this, ID_TEXT, wxT("Client on Queue:")
   	);
	wxStaticText *item4 = new wxStaticText(
 		this, ID_TEXT, wxT("0 (0 banned)")
   	);
	item2->Add( item3, 0, wxALIGN_CENTER|wxALL, 5 );
	item2->Add( 40, 10, 0, wxALIGN_CENTER|wxALL, 5 );
	item2->Add( item4, 0, wxALIGN_CENTER|wxALL, 5 );
	mainsizer->Add( item2, 0, wxALIGN_CENTER_VERTICAL|wxALL, 5 );
   	
	SetAutoLayout(TRUE);
	SetSizer(mainsizer);
	mainsizer->Fit(this);
	mainsizer->SetSizeHints(this);
}

/*
 * Download panel of the Transfer window.
 */
wxSizer* CTransferWnd::DownloadPanel(wxWindow* parent) {
	/* Topmost sizer to contain all other controls */
	wxFlexGridSizer* s_main = new wxFlexGridSizer(2, 1, 0, 0);
	s_main->AddGrowableRow(1);
	s_main->AddGrowableCol(0);

	/* Horizontal sizer to contain image, text and category notebook */
	wxFlexGridSizer* s_upper = new wxFlexGridSizer(1, 0, 0, 0);
	s_upper->AddGrowableRow(0);
	s_upper->AddGrowableCol(3);
	s_main->Add(s_upper, 0, wxGROW|wxGROW|wxLEFT|wxRIGHT|wxTOP, 5);

	/* Download icon */
	wxBitmap bmp_dload_jpg(_T("images/default/download.png"), wxBITMAP_TYPE_PNG);
	wxStaticBitmap* bmp_dload = new wxStaticBitmap(
		parent, wxID_STATIC, bmp_dload_jpg, 
		wxDefaultPosition, wxSize(16, 16), 0
	);
	s_upper->Add(
		bmp_dload, 0, wxALIGN_LEFT|wxALIGN_BOTTOM|
		wxLEFT|wxRIGHT|wxBOTTOM, 5
	);

	/* Download text */
	wxStaticText* txt_dload = new wxStaticText(
		parent, wxID_STATIC, _("Downloads (0)"), 
		wxDefaultPosition, wxDefaultSize, 0
	);
	s_upper->Add(
		txt_dload,0,wxALIGN_LEFT|wxALIGN_BOTTOM|
		wxRIGHT|wxBOTTOM|wxADJUST_MINSIZE, 5
	);

	/* A spacer to move notebook more to the right end of the frame */
	s_upper->Add(
		300, 5, 0, wxALIGN_CENTER_HORIZONTAL|
		wxALIGN_CENTER_VERTICAL|wxALL, 0
	);

	/* Category control notebook with one (default) page */
	wxNotebook* category = new wxNotebook(
		parent, ID_CATEGORY, wxDefaultPosition, 
		wxSize(-1, 25), wxNB_TOP|wxNO_BORDER
	);
	s_upper->Add(category, 0, wxGROW|wxGROW|wxALL, 0);
	wxPanel *page = new wxPanel(category, -1);
	category->AddPage(page, wxT("All"));

	/* 
	 * Download list control to fill the remainder 
	 * of the space added to main sizer.
	 */
	m_dlistctrl = new CDownloadListCtrl(
		parent, ID_LISTCTRL, wxDefaultPosition, 
		wxSize(100, 100), wxLC_REPORT|wxSUNKEN_BORDER
	);
	s_main->Add(m_dlistctrl, 0, wxGROW|wxGROW|wxLEFT|wxRIGHT, 5);

	parent->SetSizer(s_main);
	parent->SetAutoLayout(TRUE);
	return s_main;
}

/*
 * Upload panel for Transfer page.
 */
wxSizer* CTransferWnd::UploadPanel(wxWindow* parent) {
	/* Main growable sizer */
	wxFlexGridSizer* s_main = new wxFlexGridSizer(2, 0, 0, 0);
	s_main->AddGrowableRow(1);
	s_main->AddGrowableCol(0);

	/* Boxsizer to contain image and button */
	wxBoxSizer *s_upper = new wxBoxSizer( wxHORIZONTAL );
	s_main->Add( s_upper, 0, wxALIGN_CENTER_VERTICAL|wxLEFT, 5 );

	/* Upload image */
	wxBitmap img_uload(_T("images/default/upload.png"), wxBITMAP_TYPE_PNG);
	wxStaticBitmap* img = new wxStaticBitmap(
		parent, wxID_STATIC, img_uload, 
		wxDefaultPosition, wxSize(16, 16), 0
	);
	s_upper->Add(
		img, 0, wxALIGN_CENTER_HORIZONTAL|
		wxALIGN_CENTER_VERTICAL|wxALL, 5
	);

	/* Button for controlling the content of lower splitter frame */
	wxButton *btn_upload = new wxButton( 
		parent, ID_UPLOAD, _("Upload (0)"), 
		wxDefaultPosition, wxDefaultSize, wxNO_BORDER
	);
	s_upper->Add(btn_upload, 0, wxALIGN_CENTER, 5 );

	/* Upload list control */
	m_ulistctrl = new CUploadListCtrl(
		parent, ID_LISTCTRL, wxDefaultPosition, 
		wxSize(100, 100), wxLC_REPORT|wxSUNKEN_BORDER
	);
	s_main->Add(m_ulistctrl, 0, wxGROW|wxGROW|wxALL, 5);

	parent->SetSizer(s_main);
	parent->SetAutoLayout(TRUE);
	return s_main;
}

/*
 * Queue panel for Transfer window.
 */
wxSizer* CTransferWnd::QueuePanel( wxWindow *parent ) {
	/* Main sizer */
	wxFlexGridSizer *s_main = new wxFlexGridSizer( 2, 0, 0, 0 );
	s_main->AddGrowableCol( 0 );
	s_main->AddGrowableRow( 1 );

	/* Boxsizer to contain image and button*/
	wxBoxSizer *s_upper = new wxBoxSizer( wxHORIZONTAL );
	s_main->Add( s_upper, 0, wxALIGN_CENTER_VERTICAL|wxLEFT, 5 );

	/* Image */
	wxBitmap img_uload(_T("images/default/upload.png"), wxBITMAP_TYPE_PNG);
	wxStaticBitmap* img = new wxStaticBitmap(
		parent, wxID_STATIC, img_uload, 
		wxDefaultPosition, wxSize(16, 16), 0
	);
	s_upper->Add(
 		img, 0, wxALIGN_CENTER_HORIZONTAL|
   		wxALIGN_CENTER_VERTICAL|wxALL, 5
     	);

	/* Button for controlling the content of lower splitter frame */
	wxButton *btn_queue = new wxButton( 
 		parent, ID_QUEUE, _("On Queue (0)"), 
   		wxDefaultPosition, wxDefaultSize, wxNO_BORDER
	);
	s_upper->Add(btn_queue, 0, wxALIGN_CENTER, 5 );

	/* And the resizable queue list control */
	m_qlistctrl = new CQueueListCtrl( 
		parent, ID_LISTCTRL, wxDefaultPosition, 
		wxSize(160,120), wxLC_REPORT|wxSUNKEN_BORDER 
	);
	s_main->Add( m_qlistctrl, 0, wxGROW|wxALL, 5 );

	parent->SetAutoLayout( TRUE );
	parent->SetSizer( s_main);
	return s_main;
}

wxSizer* CTransferWnd::KnownPanel( wxWindow *parent ) {
	/* Main sizer */
	wxFlexGridSizer *s_main = new wxFlexGridSizer( 2, 0, 0, 0 );
	s_main->AddGrowableCol( 0 );
	s_main->AddGrowableRow( 1 );

	/* Box sizer to contain image and button */
	wxBoxSizer *s_upper = new wxBoxSizer( wxHORIZONTAL );
	s_main->Add( s_upper, 0, wxALIGN_CENTER_VERTICAL|wxLEFT, 5 );

	/* Image */
	wxBitmap img_uload(_T("images/default/upload.png"), wxBITMAP_TYPE_PNG);
	wxStaticBitmap* img = new wxStaticBitmap(
		parent, wxID_STATIC, img_uload, 
		wxDefaultPosition, wxSize(16, 16), 0
	);
	s_upper->Add(
 		img, 0, wxALIGN_CENTER_HORIZONTAL|
   		wxALIGN_CENTER_VERTICAL|wxALL, 5
     	);

     	/* Button for controlling the content of splitter lower frame */
	wxButton *btn_known = new wxButton( 
		parent, ID_KNOWN, _("Known Clients (0)"), 
		wxDefaultPosition, wxDefaultSize, wxNO_BORDER 
	);
	s_upper->Add( btn_known, 0, wxALIGN_CENTER, 5 );

	/* And add the Known clients list control to main sizer */
	m_klistctrl = new CKnownListCtrl( 
		parent, ID_LISTCTRL, wxDefaultPosition, 
		wxSize(160,120), wxLC_REPORT|wxSUNKEN_BORDER 
	);
	s_main->Add( m_klistctrl, 0, wxGROW|wxALL, 5 );

	parent->SetAutoLayout( TRUE );
	parent->SetSizer( s_main );
	return s_main;
}

